@@ -4,4 +4,5 @@ from .driver_utilities import Utilities
 from .element_finder import Finder
 from .scraping_utilities import Scraping_utilities
 
-__all__ = ["Initializer","Facebook_scraper","Utilities","Finder","Scraping_utilities"]
\ No newline at end of file
+__all__ = ["Initializer", "Facebook_scraper",
+           "Utilities", "Finder", "Scraping_utilities"]
