@@ -1,28 +1,45 @@
 #!/usr/bin/env python3
-try:
-    from seleniumwire import webdriver
-    # to add capabilities for chrome and firefox, import their Options with different aliases
-    from selenium.webdriver.chrome.options import Options as ChromeOptions
-    from selenium.webdriver.firefox.options import Options as FirefoxOptions
-    # import webdriver for downloading respective driver for the browser
-    from webdriver_manager.chrome import ChromeDriverManager
-    from webdriver_manager.firefox import GeckoDriverManager
-except Exception as ex:
-    print(ex)
+
+from seleniumwire import webdriver
+# to add capabilities for chrome and firefox, import their Options with different aliases
+from selenium.webdriver.chrome.options import Options as ChromeOptions
+from selenium.webdriver.firefox.options import Options as FirefoxOptions
+# import webdriver for downloading respective driver for the browser
+from webdriver_manager.chrome import ChromeDriverManager
+from webdriver_manager.firefox import GeckoDriverManager
+import logging
+
+logger = logging.getLogger(__name__)
+format = logging.Formatter(
+    "%(asctime)s - %(name)s - %(levelname)s - %(message)s")
+ch = logging.StreamHandler()
+ch.setFormatter(format)
+logger.addHandler(ch)
 
 
 class Initializer:
 
-    def __init__(self, browser_name, proxy=None, headless=True):
+    def __init__(self, browser_name, proxy=None, headless=True, profile=None):
         self.browser_name = browser_name
         self.proxy = proxy
         self.headless = headless
+        self.profile = profile
 
     def set_properties(self, browser_option):
         """adds capabilities to the driver"""
         if self.headless:
             browser_option.add_argument(
                 '--headless')  # runs browser in headless mode
+        if self.profile and self.browser_name.lower() == "chrome":
+            logger.setLevel(logging.INFO)
+            logger.info("Loading Profile from {}".format(self.profile))
+            browser_option.add_argument(
+                "user-data-dir={}".format(self.profile))
+        if self.profile and self.browser_name.lower() == "firefox":
+            logger.setLevel(logging.INFO)
+            logger.info("Loading Profile from {}".format(self.profile))
+            browser_option.add_argument("-profile")
+            browser_option.add_argument(self.profile)
         browser_option.add_argument('--no-sandbox')
         browser_option.add_argument("--disable-dev-shm-usage")
         browser_option.add_argument('--ignore-certificate-errors')
@@ -30,14 +47,11 @@ class Initializer:
         browser_option.add_argument('--log-level=3')
         browser_option.add_argument('--disable-notifications')
         browser_option.add_argument('--disable-popup-blocking')
-
-        # browser_option.add_argument(
-        #   "--proxy-server=http://{}".format(self.proxy.replace(" ", "")))
-
         return browser_option
 
     def set_driver_for_browser(self, browser_name):
         """expects browser name and returns a driver instance"""
+        logger.setLevel(logging.INFO)
         # if browser is suppose to be chrome
         if browser_name.lower() == "chrome":
             browser_option = ChromeOptions()
@@ -48,7 +62,7 @@ class Initializer:
                     'http': 'http://{}'.format(self.proxy.replace(" ", "")),
                     'no_proxy': 'localhost, 127.0.0.1'
                 }
-                print("Using: {}".format(self.proxy))
+                logger.info("Using: {}".format(self.proxy))
                 return webdriver.Chrome(executable_path=ChromeDriverManager().install(),
                                         options=self.set_properties(browser_option), seleniumwire_options=options)
 
@@ -61,7 +75,7 @@ class Initializer:
                     'http': 'http://{}'.format(self.proxy.replace(" ", "")),
                     'no_proxy': 'localhost, 127.0.0.1'
                 }
-                print("Using: {}".format(self.proxy))
+                logger.info("Using: {}".format(self.proxy))
                 return webdriver.Firefox(executable_path=GeckoDriverManager().install(),
                                          options=self.set_properties(browser_option), seleniumwire_options=options)
 
